@@ -4,6 +4,6 @@
 __author__ = 'Young King'
 __email__ = 'yanckin@gmail.com'
 __version__ = '0.0.1'
-from .protocol import encode, decode
+from .protocol import encode, decode, parse_stream
 
 __all__ = ["encode", "decode"]
